@@ -6,14 +6,15 @@
 mod macros;
 mod impls;
 
-use core::{any::TypeId, ops::Deref, ptr};
+use core::{any::TypeId, ptr};
 
 /// The [`Pointee::Metadata`][ptr::Pointee::Metadata] of `U`.
 pub type Metadata<U> = <U as ptr::Pointee>::Metadata;
 
 /// A type that inherits [`Pointee::Metadata`][ptr::Pointee::Metadata]
 /// from a contained type, and whose pointers are therefore coercible if that
-/// contained type is coercible.
+/// contained type is coercible.  Similar semantics as [`InnermostTypeId`]
+/// except also safe for raw pointers.
 ///
 /// # Safety
 /// The safety of unsafe code in rattish depends upon this trait being correctly
@@ -42,9 +43,22 @@ pub unsafe trait Coercible {
     /// just `Self`), this should just delegate to the contained type's
     /// `Innermost`.
     type Innermost: ?Sized;
+}
 
+/// The type that `T` will become if its contained type is coerced to `U`.
+#[allow(type_alias_bounds)]
+pub type Coerced<T: Coercible, U> = T::Coerced<U>;
+
+/// A type that inherits [`Pointee::Metadata`][ptr::Pointee::Metadata]
+/// from a contained type, and whose pointers are therefore coercible if that
+/// contained type is coercible.
+///
+/// # Safety
+/// The safety of unsafe code in rattish depends upon this trait being correctly
+/// implemented.
+pub unsafe trait InnermostTypeId {
     /// Returns the [`TypeId`] of the *concrete* value underlying
-    /// [`Innermost`][Coercible::Innermost].
+    /// [`<Self as ptr::Pointee>::Metadata`].
     ///
     /// Unless `Self` is a leaf, such as a `dyn Trait` (in which case this
     /// should delegate to a trait method), this should just delegate to the
@@ -52,16 +66,15 @@ pub unsafe trait Coercible {
     fn innermost_type_id(&self) -> TypeId;
 }
 
-/// The type that `T` will become if its contained type is coerced to `U`.
-#[allow(type_alias_bounds)]
-pub type Coerced<T: Coercible, U> = T::Coerced<U>;
-
 /// A pointer-type to a [`Coercible`].
 pub trait Pointer<'a>
 where
-    Self: Coercible + Deref + Sized,
-    Self::Target: Coercible,
+    Self: Coercible + Sized,
 {
+    /// Basically the same as [`Deref::Target`][core::ops::Deref::Target], but
+    /// without any dereferencing so is safe for raw pointers too.
+    type Target: ?Sized + Coercible;
+
     /// Perform the coercion.
     ///
     /// # Safety
